@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2024 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -192,7 +192,6 @@ static SDL_TimerID SDLTest_SetTestTimeout(int timeout, SDL_TimerCallback callbac
         SDLTest_LogError("Timeout callback can't be NULL");
         return 0;
     }
-
     if (timeout < 0) {
         SDLTest_LogError("Timeout value must be bigger than zero.");
         return 0;
@@ -200,7 +199,7 @@ static SDL_TimerID SDLTest_SetTestTimeout(int timeout, SDL_TimerCallback callbac
 
     /* Set timer */
     timeoutInMilliseconds = timeout * 1000;
-    timerID = SDL_AddTimer(timeoutInMilliseconds, callback, 0x0);
+    timerID = SDL_AddTimer(timeoutInMilliseconds, callback, NULL);
     if (timerID == 0) {
         SDLTest_LogError("Creation of SDL timer failed: %s", SDL_GetError());
         return 0;
@@ -515,6 +514,7 @@ int SDLTest_ExecuteTestSuiteRunner(SDLTest_TestSuiteRunner *runner)
 
     arraySuites = SDL_malloc(nbSuites * sizeof(int));
     if (!arraySuites) {
+        SDL_free((void *)failedTests);
         return SDL_OutOfMemory();
     }
     for (i = 0; i < nbSuites; i++) {
@@ -586,6 +586,8 @@ int SDLTest_ExecuteTestSuiteRunner(SDLTest_TestSuiteRunner *runner)
 
             arrayTestCases = SDL_malloc(nbTestCases * sizeof(int));
             if (!arrayTestCases) {
+                SDL_free(arraySuites);
+                SDL_free((void *)failedTests);
                 return SDL_OutOfMemory();
             }
             for (j = 0; j < nbTestCases; j++) {
